==> haskell-list-t-1.0.5.5-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-list-t.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 list-t
version:              1.0.5.5
visibility:           public
id:                   list-t-1.0.5.5-Bq2yPc85Te9FvgzM9vvZa6
key:                  list-t-1.0.5.5-Bq2yPc85Te9FvgzM9vvZa6
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/list-t
synopsis:             ListT done right
description:
    A correct implementation of the list monad-transformer.
    Useful for basic streaming.

category:             Streaming, Data Structures, Control
abi:                  64ce0f218bc78838ea63581727310b86
exposed:              True
exposed-modules:      ListT
hidden-modules:       ListT.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-list-t
hs-libraries:         HSlist-t-1.0.5.5-Bq2yPc85Te9FvgzM9vvZa6
depends:
    base-4.17.2.1 foldl-1.4.17-5NiA5jobkso4X3evSS7QhM
    logict-0.7.1.0-GwXyMxqvqDHKoFcBRhqDz3
    mmorph-1.2.0-3nIz0RIlBAUER45blfkK28
    monad-control-1.0.3.1-9kuNlqWAv0v3CZ7ezVGs4u mtl-2.2.2
    transformers-0.5.6.2 transformers-base-0.4.6-L9QACCq37DSHBaBrNyzkap

haddock-interfaces:   /usr/share/doc/haskell-list-t/html/list-t.haddock
haddock-html:         /usr/share/doc/haskell-list-t/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-list-t-1.0.5.5-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-list-t.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 list-t
version:              1.0.5.5
visibility:           public
id:                   list-t-1.0.5.5-1aCFTOnbvILIZ4YnC9XY9Y
key:                  list-t-1.0.5.5-1aCFTOnbvILIZ4YnC9XY9Y
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/list-t
synopsis:             ListT done right
description:
    A correct implementation of the list monad-transformer.
    Useful for basic streaming.

category:             Streaming, Data Structures, Control
abi:                  4afc5dc09cd7749d053de4237e838ae1
exposed:              True
exposed-modules:      ListT
hidden-modules:       ListT.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/list-t-1.0.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-list-t
hs-libraries:         HSlist-t-1.0.5.5-1aCFTOnbvILIZ4YnC9XY9Y
depends:
    base-4.17.2.1 foldl-1.4.17-2npyujTsVhGBUsY9gx2uZY
    logict-0.7.1.0-DgJc6ddXzUf1bPXT9IOQ5j
    mmorph-1.2.0-3nIz0RIlBAUER45blfkK28
    monad-control-1.0.3.1-7R10NVdb48W9RXFDqz7pZ0 mtl-2.2.2
    transformers-0.5.6.2 transformers-base-0.4.6-9GQL5dr8RbxCW0vUqKz2fC

haddock-interfaces:   /usr/share/doc/haskell-list-t/html/list-t.haddock
haddock-html:         /usr/share/doc/haskell-list-t/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
